@@ -45,7 +45,7 @@
 
 #define CHECK_EVERY_X_SECONDS      60
 
-#define DISK_SPACE_ANALYZER        "ukui-disk-usage-analyzer"
+#define DISK_SPACE_ANALYZER        "mate-disk-usage-analyzer"
 
 #define SETTINGS_HOUSEKEEPING_SCHEMA      "org.ukui.SettingsDaemon.plugins.housekeeping"
 #define SETTINGS_FREE_PC_NOTIFY_KEY       "free-percent-notify"
