@@ -37,6 +37,7 @@
 #include <gtk/gtk.h>
 #include <X11/keysym.h>
 #include <gio/gio.h>
+#include <gio/gdesktopappinfo.h>
 #include <dconf.h>
 
 #include "ukui-settings-profile.h"
@@ -46,6 +47,7 @@
 #include "usd-keygrab.h"
 #include "eggaccelerators.h"
 
+#define DESKTOP_APP_DIR "/usr/share/applications/"
 #define GSETTINGS_KEYBINDINGS_DIR "/org/ukui/desktop/keybindings/"
 #define CUSTOM_KEYBINDING_SCHEMA "org.ukui.control-center.keybinding"
 
@@ -119,7 +121,6 @@ parse_binding (Binding *binding)
             g_strcmp0 (binding->binding_str, "disabled") == 0 ) {
                 return FALSE;
         }
-
         success = egg_accelerator_parse_virtual (binding->binding_str,
                                                  &binding->key.keysym,
                                                  &binding->key.keycodes,
@@ -360,9 +361,9 @@ binding_register_keys (UsdKeybindingsManager *manager)
                                 binding->previous_key.keysym = binding->key.keysym;
                                 binding->previous_key.state = binding->key.state;
                                 g_free (binding->previous_key.keycodes);
-                                for (i = 0; binding->key.keycodes[i]; ++i);
+                                for (i = 0; binding->key.keycodes&&binding->key.keycodes[i]; ++i);
                                 binding->previous_key.keycodes = g_new0 (guint, i);
-                                for (i = 0; binding->key.keycodes[i]; ++i)
+                                for (i = 0; binding->key.keycodes&&binding->key.keycodes[i]; ++i)
                                         binding->previous_key.keycodes[i] = binding->key.keycodes[i];
                         } else
                                 g_warning ("Key binding (%s) is already in use", binding->binding_str);
@@ -485,7 +486,7 @@ keybindings_filter (GdkXEvent             *gdk_xevent,
                         }
 
                         envp = get_exec_environment (xevent);
-
+                        /*
                         retval = g_spawn_async (NULL,
                                                 argv,
                                                 envp,
@@ -494,6 +495,11 @@ keybindings_filter (GdkXEvent             *gdk_xevent,
                                                 NULL,
                                                 NULL,
                                                 &error);
+                        */
+						char execPathName[255];
+						sprintf(execPathName, "%s%s", DESKTOP_APP_DIR, binding->action);
+                        GDesktopAppInfo *info = g_desktop_app_info_new_from_filename(execPathName);
+						retval = g_app_info_launch_uris(info, NULL, NULL, NULL);
                         g_strfreev (argv);
                         g_strfreev (envp);
 
