@@ -327,7 +327,6 @@ touchpad_set_bool (XDeviceInfo *device_info,
         if (device == NULL) {
                 return;
         }
-
         property_set_bool (device_info, device, property_name, property_index, enabled);
 
         gdk_error_trap_push ();
@@ -997,7 +996,7 @@ set_tap_to_click_all (UsdMouseManager *manager)
         gint three_finger_tap = g_settings_get_int (manager->priv->settings_touchpad, KEY_TOUCHPAD_THREE_FINGER_TAP);
 
         for (i = 0; i < numdevices; i++) {
-//                set_tap_to_click (&devicelist[i], state, left_handed, one_finger_tap, two_finger_tap, three_finger_tap);
+                set_tap_to_click (&devicelist[i], state, left_handed, one_finger_tap, two_finger_tap, three_finger_tap);
         }
 
         XFreeDeviceList (devicelist);
@@ -1237,8 +1236,9 @@ set_scrolling_libinput (XDeviceInfo *device_info,
         gboolean want_horiz;
 
         prop = property_from_name ("libinput Scroll Method Enabled");
-        if (!prop)
+        if (!prop) {
                 return;
+	}
 
         device = device_is_touchpad (device_info);
         if (device == NULL) {
@@ -1280,10 +1280,12 @@ set_scrolling_libinput (XDeviceInfo *device_info,
          * there's only one bool. Pick the one matching the scroll method
          * we picked above.
          */
-        if (want_2fg)
+        if (want_2fg) {
                 want_horiz = g_settings_get_boolean (settings, KEY_HORIZ_TWO_FINGER_SCROLL);
-        else if (want_edge)
+	}
+        else if (want_edge) {
                 want_horiz = g_settings_get_boolean (settings, KEY_HORIZ_EDGE_SCROLL);
+	}
         else
                 return;
 
@@ -1522,7 +1524,7 @@ touchpad_callback (GSettings          *settings,
                 || (g_strcmp0 (key, KEY_TOUCHPAD_TWO_FINGER_TAP) == 0)
                 || (g_strcmp0 (key, KEY_TOUCHPAD_THREE_FINGER_TAP) == 0)) {
                 set_tap_to_click_all (manager);
-/* Do not set click actions since ukwm take over this 
+/* Do not set click actions since ukwm take over this
  *        } else if ((g_strcmp0 (key, KEY_TOUCHPAD_TWO_FINGER_CLICK) == 0)
  *               || (g_strcmp0 (key, KEY_TOUCHPAD_THREE_FINGER_CLICK) == 0)) {
  *               set_click_actions_all (manager);
@@ -1570,7 +1572,7 @@ usd_mouse_manager_idle_cb (UsdMouseManager *manager)
 
 #if 0   /* FIXME need to fork (?) mousetweaks for this to work */
         set_mousetweaks_daemon (manager,
-                                g_settings_get_boolean (manager->priv->settings_mouse_a11y, 
+                                g_settings_get_boolean (manager->priv->settings_mouse_a11y,
                                                         KEY_MOUSE_A11Y_DWELL_ENABLE),
                                 g_settings_get_boolean (manager->priv->settings_mouse_a11y,
                                                         KEY_MOUSE_A11Y_DELAY_ENABLE));
