@@ -41,6 +41,12 @@
 #include <gio/gio.h>
 #include <dbus/dbus-glib.h>
 
+#include <X11/extensions/XInput2.h>
+#include <X11/XKBlib.h>
+#include <X11/keysym.h>
+#include <X11/Xatom.h>
+#include <X11/extensions/XInput.h>
+
 #define MATE_DESKTOP_USE_UNSTABLE_API
 #include <libmate-desktop/mate-rr-config.h>
 #include <libmate-desktop/mate-rr.h>
@@ -1542,6 +1548,20 @@ apply_color_profiles (void)
         }
 }
 
+/*检测到旋转，更改触摸屏鼠标光标位置*/
+void set_touchscreen_cursor(void *date)
+{
+        Display *xdisplay = XOpenDisplay(NULL);
+        Atom property_atom;
+        property_atom = XInternAtom (xdisplay, "Coordinate Transformation Matrix", True);
+        if (!property_atom)
+            return;
+        Atom type = XInternAtom (xdisplay, "FLOAT", False);
+        XIChangeProperty (xdisplay, XITouchClass, property_atom, type,
+                          32, XIPropModeReplace, date, 9);
+        XCloseDisplay(xdisplay);
+}
+
 static void
 on_randr_event (MateRRScreen *screen, gpointer data)
 {
@@ -1618,6 +1638,50 @@ on_randr_event (MateRRScreen *screen, gpointer data)
                         log_msg ("Applied stored configuration to deal with event\n");
         }
 
+        /* 添加触摸屏鼠标设置 */
+        MateRRConfig *result;
+        MateRROutputInfo **outputs;
+        int i;
+        result = mate_rr_config_new_current (screen, NULL);
+        outputs = mate_rr_config_get_outputs (result);
+        for(i=0; outputs[i] != NULL;++i)
+        {
+            MateRROutputInfo *info = outputs[i];
+            if(mate_rr_output_info_is_connected (info)){
+                int rotation = mate_rr_output_info_get_rotation(info);
+                switch(rotation){
+                    case MATE_RR_ROTATION_0:
+                    {
+                        float full_matrix[9] = {1, 0, 0, 0, 1, 0, 0, 0, 1};
+                        set_touchscreen_cursor(&full_matrix);
+                        break;
+                    }
+                    case MATE_RR_ROTATION_90:
+                    {
+                        float full_matrix[9] = {0, -1, 1, 1, 0, 0, 0, 0, 1};
+                        set_touchscreen_cursor(&full_matrix);
+                        break;
+                    }
+                    case MATE_RR_ROTATION_180:
+                    {
+                        float full_matrix[9] = {-1,  0, 1, 0, -1, 1, 0, 0, 1};
+                        set_touchscreen_cursor(&full_matrix);
+                        break;
+                    }
+                    case MATE_RR_ROTATION_270:
+                    {
+                        float full_matrix[9] = {0, 1, 0, -1, 0, 1, 0, 0, 1};
+                        set_touchscreen_cursor(&full_matrix);
+                        break;
+                    }
+                    default:
+                    {
+                        float full_matrix[9] = {1, 0, 0, 0, 1, 0, 0, 0, 1};
+                        set_touchscreen_cursor(&full_matrix);
+                    }
+                }
+            }
+        }
         /* poke mate-color-manager */
         apply_color_profiles ();
 
@@ -2383,7 +2447,50 @@ usd_xrandr_manager_start (UsdXrandrManager *manager,
         gdk_window_add_filter (gdk_get_default_root_window(),
                                (GdkFilterFunc)event_filter,
                                manager);
-
+        /* 添加触摸屏鼠标设置 */
+        MateRRConfig *result;
+        MateRROutputInfo **outputs;
+        int i;
+        result = mate_rr_config_new_current (manager->priv->rw_screen, NULL);
+        outputs = mate_rr_config_get_outputs (result);
+        for(i=0; outputs[i] != NULL;++i)
+        {
+            MateRROutputInfo *info = outputs[i];
+            if(mate_rr_output_info_is_connected (info)){
+                int rotation = mate_rr_output_info_get_rotation(info);
+                switch(rotation){
+                    case MATE_RR_ROTATION_0:
+                    {
+                        float full_matrix[9] = {1, 0, 0, 0, 1, 0, 0, 0, 1};
+                        set_touchscreen_cursor(&full_matrix);
+                        break;
+                    }
+                    case MATE_RR_ROTATION_90:
+                    {
+                        float full_matrix[9] = {0, -1, 1, 1, 0, 0, 0, 0, 1};
+                        set_touchscreen_cursor(&full_matrix);
+                        break;
+                    }
+                    case MATE_RR_ROTATION_180:
+                    {
+                        float full_matrix[9] = {-1,  0, 1, 0, -1, 1, 0, 0, 1};
+                        set_touchscreen_cursor(&full_matrix);
+                        break;
+                    }
+                    case MATE_RR_ROTATION_270:
+                    {
+                        float full_matrix[9] = {0, 1, 0, -1, 0, 1, 0, 0, 1};
+                        set_touchscreen_cursor(&full_matrix);
+                        break;
+                    }
+                    default:
+                    {
+                        float full_matrix[9] = {1, 0, 0, 0, 1, 0, 0, 0, 1};
+                        set_touchscreen_cursor(&full_matrix);
+                    }
+                }
+            }
+        }
         start_or_stop_icon (manager);
 
         log_close ();
