@@ -44,8 +44,6 @@
 #include "xsettings-manager.h"
 #include "fontconfig-monitor.h"
 
-#include "syslog.h"
-
 #define UKUI_XSETTINGS_MANAGER_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), UKUI_TYPE_XSETTINGS_MANAGER, UkuiXSettingsManagerPrivate))
 
 #define MOUSE_SCHEMA          "org.ukui.peripherals-mouse"
@@ -415,7 +413,7 @@ update_property (GString *props, const gchar* key, const gchar* value)
         needle_len = strlen (needle);
         if (g_str_has_prefix (props->str, needle))
                 found = props->str;
-        else 
+        else
                 found = strstr (props->str, needle);
 
         if (found) {
@@ -456,15 +454,14 @@ xft_settings_set_xresources (UkuiXftSettings *settings)
 		strncpy(tmpCursorTheme, settings->cursor_theme, 255);
 	} else {
 		// unset, use default
-		strncpy(tmpCursorTheme, "Breeze_Snow", 255);
-	        syslog(LOG_ERR, "use default theme name=%s=", tmpCursorTheme);
+		strncpy(tmpCursorTheme, "DMZ-White", 255);
 	}
 	if (settings->cursor_size > 0) {
 		tmpCursorSize = settings->cursor_size;
 	} else {
 		tmpCursorSize = XcursorGetDefaultSize(dpy);
 	}
-	// end add by liutong 
+	// end add by liutong
 
         update_property (add_string, "Xft.dpi",
                                 g_ascii_dtostr (dpibuf, sizeof (dpibuf), (double) settings->dpi / 1024.0));
@@ -504,7 +501,6 @@ xft_settings_set_xresources (UkuiXftSettings *settings)
 	    for (int i = 0; i < len-1; i++) {
                 XcursorImages *images = XcursorLibraryLoadImages(qtCursorsNames[i], tmpCursorTheme, tmpCursorSize);
 	        if (!images) {
-	             syslog(LOG_ERR, "null images, theme name=%s, imageName=%s=", tmpCursorTheme, qtCursorsNames[i]);
                      g_debug("xcursorlibrary load images :null image, theme name=%s", tmpCursorTheme);
 		     continue;
 	        }
